SystemOrganization addCategory: #'FLOdactic-Tests'!

TestCase subclass: #DidacticMaterialsManagerFieldsTests
	instanceVariableNames: 'material material1 material2 manager user'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FLOdactic-Tests'!

!DidacticMaterialsManagerFieldsTests methodsFor: 'as yet unclassified' stamp: 'it 5/11/2013 19:06'!
setUp
	"Variables setup for the test"
	
	material := DidacticMaterial new.
	material1 := DidacticMaterial new.
	material2 := DidacticMaterial new.
	
	user := User new.
	
	manager := DidacticMaterialsManager new.
! !

!DidacticMaterialsManagerFieldsTests methodsFor: 'as yet unclassified' stamp: 'it 5/11/2013 19:07'!
testAddWithEmptyDescription
	"comment stating purpose of message"

	material uri: 'uri'; title: 'title'; type: 'type'; license: 'license'.
	
	self should: [manager owner: user add: material] raise: ValidationError.! !

!DidacticMaterialsManagerFieldsTests methodsFor: 'as yet unclassified' stamp: 'it 5/11/2013 19:09'!
testAddWithEmptyLicense
	"comment stating purpose of message"

	material uri: 'uri'; title: 'title'; description: 'description'; type: 'type'.
	
	self should: [manager owner: user add: material] raise: ValidationError.! !

!DidacticMaterialsManagerFieldsTests methodsFor: 'as yet unclassified' stamp: 'it 5/11/2013 19:09'!
testAddWithEmptyTitle
	"comment stating purpose of message"

	material uri: 'uri'; description: 'description'; type: 'type'; license: 'license'.
	
	self should: [manager owner: user add: material] raise: ValidationError.! !

!DidacticMaterialsManagerFieldsTests methodsFor: 'as yet unclassified' stamp: 'it 5/11/2013 19:09'!
testAddWithEmptyType
	"comment stating purpose of message"

	material uri: 'uri'; title: 'title'; description: 'description'; license: 'license'.
	
	self should: [manager owner: user add: material] raise: ValidationError.! !

!DidacticMaterialsManagerFieldsTests methodsFor: 'as yet unclassified' stamp: 'it 5/11/2013 19:09'!
testAddWithEmptyUri
	"comment stating purpose of message"

	material title: 'title'; description: 'description'; type: 'type'; license: 'license'.
	
	self should: [manager owner: user add: material] raise: ValidationError.! !

!DidacticMaterialsManagerFieldsTests methodsFor: 'as yet unclassified' stamp: 'it 5/11/2013 19:13'!
testAddWithSameUri
	"comment stating purpose of message"

	material1 uri: 'uri'; title: 'title'; description: 'description'; type: 'type'; license: 'license'.
	material2 uri: 'uri'; title: 'title'; description: 'description'; type: 'type'; license: 'license'.
	
	manager owner: user add: material1.
	
	self should: [manager owner: user add: material2] raise: ValidationError.! !

!DidacticMaterialsManagerFieldsTests methodsFor: 'as yet unclassified' stamp: 'it 5/11/2013 19:20'!
testAddWithSameUriSameObject
	"comment stating purpose of message"

	material uri: 'uri'; title: 'title'; description: 'description'; type: 'type'; license: 'license'.
	manager owner: user add: material.
	
	material description: 'changed description'.
	manager validate: material.
	
	self assert: [(manager items at: 'uri') description = 'changed description']! !

TestCase subclass: #DidacticMaterialsManagerTests
	instanceVariableNames: 'material material1 material2 manager manager1 user1 user2 testuser1 testuser2 testmaterial1 testmaterial2 testmanager1 testmaterial3 author1 author2'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FLOdactic-Tests'!

!DidacticMaterialsManagerTests methodsFor: 'as yet unclassified' stamp: 'afv 5/10/2013 18:17'!
setUp
	"Variables setup for the test"
	
	author1 := Author new.
	author1 name: 'Albert De La Fuente'.
	author2 := Author new.
	author2 name: 'Igor Topcin'.
	testuser1 := User new.
	testuser1 username: 'user1'; password: 'q'; name: 'user1'; email: 'user1@flodactic.org'; withUserPrivileges; doEnable..
	testuser2 := User new.
	testuser2 username: 'user2'; password: 'q'; name: 'user2'; email: 'user2@flodactic.org'; withUserPrivileges; doEnable...

	testmaterial1 := DidacticMaterial new.
	testmaterial1 uri: 'http://www.albertdelafuente.com/doku.php/wiki/devel/python/ldap-auth';
			title: 'Python LDAP tutorial';
			description: 'A tutorial on how to use an LDAP server on Python';
			type: 'document';
			license: 'cc';
			addAuthor: author1.
			
	testmaterial2 := DidacticMaterial new.
	testmaterial2 uri: 'http://www.albertdelafuente.com/doku.php/wiki/devel/python/whatsapp-api';
			title: 'Python Whatsapp tutorial';
			description: 'A tutorial on how to use an Whatsapp API on Python';
			type: 'document';
			license: 'cc-ca';
			addAuthor: author1.
			
	testmaterial3 := DidacticMaterial new.
	testmaterial3 uri: 'https://github.com/poo2013pos/FLOdactic';
			title: 'FLOdactic: A Free Libre Open didactic management system';
			description: 'A Free Libre Open didactic management system made in Smalltalk for the 2013 OOP course at Universidade de Sao Paulo';
			type: 'Source Code';
			license: 'GPLv2';
			addAuthor: author1;
			addAuthor: author2.

	testmanager1 := DidacticMaterialsManager new.! !

!DidacticMaterialsManagerTests methodsFor: 'as yet unclassified' stamp: 'afv 5/11/2013 23:09'!
tearDown
	"Executed after the tests"
	
	testmanager1 remove: testmaterial1.
	testmanager1 remove: testmaterial2.
	testmanager1 remove: testmaterial3.! !

!DidacticMaterialsManagerTests methodsFor: 'as yet unclassified' stamp: 'afv 5/4/2013 12:25'!
testDidacticMaterialManagerCounterIncrementsAfterAddingADidacticMaterial
	"Verifies that after adding a material the number of materials gets incremented. It might be silly since the Dictionary class should be already tested by its developers"

	| count |
"	user := User new.
	user username: 'testowner'; email: 'testuser@flodactic.org'.
	material uri: 'uri'; title: 'title'; description: 'description'; type: 'type'; license: 'license'."

	count  := testmanager1 size.
	testmanager1 owner: testuser1 add: testmaterial1.
"	testmanager1 owner: testuser1 add: testmaterial2."
	self assert: ((testmanager1 size) = (count + 1)).! !

!DidacticMaterialsManagerTests methodsFor: 'as yet unclassified' stamp: 'afv 5/6/2013 17:51'!
testNestedSelectByTitleContains
	""

	| select1 select2 |
	self tearDown.
	self setUp.
	testmanager1 owner: testuser1 add: testmaterial1.
	testmanager1 owner: testuser1 add: testmaterial2.
	select1 := testmanager1 select: [:doc | (doc title findString: 'Python') > 0].
	self assert: ((select1 size) = 2).
	
	select2 := select1 select: [:doc | (doc title findString: 'Whatsapp') > 0].
	self assert: ((select2 size) = 1).
	
! !

!DidacticMaterialsManagerTests methodsFor: 'as yet unclassified' stamp: 'afv 5/7/2013 19:54'!
testSelectAuthorsByName
	"Albert is author of 3 materials and Igor is author of 1"

	| result |
	self tearDown.
	self setUp.
	testmanager1 owner: testuser1 add: testmaterial1.
	testmanager1 owner: testuser1 add: testmaterial2.
	testmanager1 owner: testuser1 add: testmaterial3.
	
	result := testmaterial1 selectAuthorsByName: 'Albert De La Fuente'.
	self assert: ((result size) = 1).
	result := testmaterial3 selectAuthorsByName: 'Igor Topcin'.
	self assert: ((result size) = 1).! !

!DidacticMaterialsManagerTests methodsFor: 'as yet unclassified' stamp: 'afv 5/6/2013 18:14'!
testSimpleSelectByLicense
	""

	| result |
	self tearDown.
	self setUp.
	testmanager1 owner: testuser1 add: testmaterial1.
	testmanager1 owner: testuser1 add: testmaterial2.
	testmanager1 owner: testuser1 add: testmaterial3.
	result := testmanager1 select: [:doc | doc license = 'GPLv2'].
	
	self assert: ((result size) = 1).
	
! !

!DidacticMaterialsManagerTests methodsFor: 'as yet unclassified' stamp: 'afv 5/6/2013 17:58'!
testSimpleSelectByUri
	""

	| result |
	self tearDown.
	self setUp.
	testmanager1 owner: testuser1 add: testmaterial1.
	testmanager1 owner: testuser1 add: testmaterial2.
	result := testmanager1 select: [:doc | doc uri = 'http://www.albertdelafuente.com/doku.php/wiki/devel/python/ldap-auth'].
	
	self assert: ((result size) = 1).
	
! !

TestCase subclass: #FLOdacticFacadeTests
	instanceVariableNames: 'testui'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FLOdactic-Tests'!

FLOdacticFacadeTests class
	instanceVariableNames: 'testui user login'!

FLOdacticFacadeTests class
	instanceVariableNames: 'testui user login'!

!FLOdacticFacadeTests methodsFor: 'as yet unclassified' stamp: 'it 5/11/2013 20:02'!
setUp
	"Variables setup for the test"
	|user|
	
	testui := FLOdacticFacade newTestsInstance.
	
	user := User new.
	user username: 'albert'; password: 'pass'; name: 'Albert'; email: 'vonpupp@gmail.com'; withUserPrivileges; doEnable.
	testui addUser: user.
	
	user := User new.
	user username: 'john'; password: 'pwd1'; name: 'John Smith'; email: 'john@flodactic.org'; withUserPrivileges; doEnable.
	testui addUser: user.
	
	user := User new.
	user username: 'joane'; password: 'pwd2'; name: 'Joane Smith'; email: 'joane@flodactic.org'; withUserPrivileges; doEnable.
	testui addUser: user.
	
	user := User new.
	user username: 'bob'; password: 'pwd3'; name: 'Robert Williams'; email: 'bob@flodactic.org'; withUserPrivileges; doEnable.
	testui addUser: user.! !

!FLOdacticFacadeTests methodsFor: 'as yet unclassified' stamp: 'afv 5/10/2013 14:11'!
tearDown
	"Executed after the test"

	testui removeUser: 'albert'.
	testui removeAll.
	testui release.
! !

!FLOdacticFacadeTests methodsFor: 'as yet unclassified' stamp: 'it 5/11/2013 19:58'!
testFailedLoginUsernamePassword
	"comment stating purpose of message"

	self should: [testui doLogin: 'albert' password: 'wrong'..] raise: PermissionError.
! !

!FLOdacticFacadeTests methodsFor: 'as yet unclassified' stamp: 'it 5/11/2013 21:30'!
testSearchUsers
	"comment stating purpose of message"

	| results |
	results := testui searchUsers: '*Smith*'.
	self assert: [results size = 2].
	self assert: [results includesKey: 'john'].
	self assert: [results includesKey: 'joane'].

	results := testui searchUsers: 'bob@flodactic.org'.
	self assert: [results size = 1].
	self assert: [results includesKey: 'bob'].
! !

!FLOdacticFacadeTests methodsFor: 'as yet unclassified' stamp: 'afv 5/10/2013 11:00'!
testSuccessfulLoginUsernamePassword
	"comment stating purpose of message"

	| login |

	self tearDown.
	self setUp.
	testui loggedUser ifNotNil: [
		testui doLogout.
	].
	login := testui doLogin: 'albert' password: 'pass'.
	self assert: (login = true).! !

TestCase subclass: #UsersManagerFieldsTests
	instanceVariableNames: 'admin admin1 admin2 usersManager facade'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FLOdactic-Tests'!

!UsersManagerFieldsTests methodsFor: 'as yet unclassified' stamp: 'it 5/11/2013 19:51'!
setUp
	"Variables setup for the test"
	
	admin := User new.
	admin1 := User new.
	admin2 := User new.
	
	usersManager := UsersManager new.! !

!UsersManagerFieldsTests methodsFor: 'as yet unclassified' stamp: 'afv 4/30/2013 21:57'!
tearDown
	"Executed after the test"! !

!UsersManagerFieldsTests methodsFor: 'as yet unclassified' stamp: 'it 5/11/2013 19:48'!
testAddWithEmptyEmail
	"comment stating purpose of message"

	admin username: 'admin'; password: 'q'; name: 'Leonardo Santos'; withAdminPrivileges; doEnable.
	
	self should: [usersManager add: admin.] raise: ValidationError! !

!UsersManagerFieldsTests methodsFor: 'as yet unclassified' stamp: 'it 5/11/2013 19:48'!
testAddWithEmptyName
	"comment stating purpose of message"

	admin username: 'admin'; password: 'q'; email: 'leo@flodactic.org'; withAdminPrivileges; doEnable.
	
	self should: [usersManager add: admin.] raise: ValidationError! !

!UsersManagerFieldsTests methodsFor: 'as yet unclassified' stamp: 'it 5/11/2013 19:48'!
testAddWithEmptyPassword
	"comment stating purpose of message"

	admin username: 'admin'; name: 'Leonardo Santos'; email: 'leo@flodactic.org'; withAdminPrivileges; doEnable..
	
	self should: [usersManager add: admin.] raise: ValidationError! !

!UsersManagerFieldsTests methodsFor: 'as yet unclassified' stamp: 'it 5/11/2013 19:49'!
testAddWithEmptyRole
	"comment stating purpose of message"

	admin username: 'admin'; password: 'q'; name: 'Leonardo Santos'; email: 'leo@flodactic.org'; doEnable..
	
	self should: [usersManager add: admin.] raise: ValidationError! !

!UsersManagerFieldsTests methodsFor: 'as yet unclassified' stamp: 'it 5/11/2013 19:49'!
testAddWithEmptyStatus
	"comment stating purpose of message"

	admin username: 'admin'; password: 'q'; name: 'Leonardo Santos'; email: 'leo@flodactic.org'; withAdminPrivileges.
	
	self should: [usersManager add: admin.] raise: ValidationError! !

!UsersManagerFieldsTests methodsFor: 'as yet unclassified' stamp: 'it 5/11/2013 19:49'!
testAddWithEmptyUsername
	"comment stating purpose of message"

	admin password: 'q'; name: 'Leonardo Santos'; email: 'leo@flodactic.org'; withAdminPrivileges; doEnable.
	
	self should: [usersManager add: admin.] raise: ValidationError! !

!UsersManagerFieldsTests methodsFor: 'as yet unclassified' stamp: 'afv 5/10/2013 18:20'!
testMatchUsernameMatchPassword
	"comment stating purpose of message"

	admin username: 'leo'; password: 'q'; name: 'Leonardo Santos'; email: 'leo@flodactic.org'; withAdminPrivileges; doEnable.
	
	self assert: ((admin matchUsername: 'leo' matchPassword: 'q') = true).! !

!UsersManagerFieldsTests methodsFor: 'as yet unclassified' stamp: 'it 5/11/2013 19:56'!
testUserIsEnabled
	"comment stating purpose of message"

	admin username: 'john'; password: 'a'; name: 'John Smith'; email: 'john@flodactic.org'; withAdminPrivileges; doEnable.
	admin1 username: 'joane'; password: 'b'; name: 'Joane Smith'; email: 'joane@flodactic.org'; withAdminPrivileges; doEnable.
	admin2 username: 'charles'; password: 'c'; name: 'Charles Davis'; email: 'charles@flodactic.org'; withAdminPrivileges; doEnable.
	
	
	
	self assert: (admin isEnabled = true).! !

TestCase subclass: #UsersManagerTests
	instanceVariableNames: 'usersManager user user1 user2'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FLOdactic-Tests'!

!UsersManagerTests methodsFor: 'as yet unclassified' stamp: 'afv 5/10/2013 18:21'!
setUp
	"Variables setup for the test"
	
	user := User new.
	user username: 'user'; password: 'q'; name: 'Leonardo Santos'; email: 'admin@flodactic.org'; withAdminPrivileges; doEnable.
	
	user1 := User new.
	user2 := User new.
	usersManager := UsersManager new.! !

!UsersManagerTests methodsFor: 'as yet unclassified' stamp: 'afv 5/10/2013 14:22'!
tearDown
	"Variables setup for the test"
	
	user release.
	user1 release.
	user2 release.
	usersManager removeAll.! !

!UsersManagerTests methodsFor: 'as yet unclassified' stamp: 'it 5/11/2013 19:35'!
testAddWithDuplicatedEmails
	"Test for duplicated emails"

	user1 username: 'admin1'; password: 'q'; name: 'Leonardo Santos'; email: 'admin@flodactic.org'; withAdminPrivileges; doEnable.
	user2 username: 'admin1'; password: 'q'; name: 'Rodrigo Barbosa'; email: 'admin@flodactic.org'; withAdminPrivileges; doEnable.
	usersManager add: user1.
	
	self should: [usersManager add: user2.] raise: ValidationError! !

!UsersManagerTests methodsFor: 'as yet unclassified' stamp: 'it 5/11/2013 19:35'!
testAddWithDuplicatedUsername
	"Test for duplicated usernames"

	self tearDown.
	self setUp.
	user1 username: 'admin'; password: 'q'; name: 'Leonardo Santos'; email: 'leo@flodactic.org'; withAdminPrivileges; doEnable.
	user2 username: 'admin'; password: 'q'; name: 'Rodrigo Barbosa'; email: 'rodrigo@flodactic.org'; withAdminPrivileges; doEnable.
	usersManager add: user1.
	
	self should: [usersManager add: user2.] raise: ValidationError! !

!UsersManagerTests methodsFor: 'as yet unclassified' stamp: 'it 5/11/2013 19:37'!
testDoLoginWithDisabledUser
	"comment stating purpose of message"

	user username: 'user'; password: 'q'; name: 'Leonardo Santos'; email: 'admin@flodactic.org'; withAdminPrivileges; doEnable.
	
	self should: [usersManager doLogin: 'user' password: 'q'.] raise: Exception! !

!UsersManagerTests methodsFor: 'as yet unclassified' stamp: 'it 5/11/2013 19:42'!
testDoLoginWithNonExistingUsername
	"comment stating purpose of message"

	user username: 'user'; password: 'q'; name: 'Leonardo Santos'; email: 'admin@flodactic.org'; withAdminPrivileges; doEnable.
	
	self should: [usersManager doLogin: 'u' password: 'q'.] raise: PermissionError! !

!UsersManagerTests methodsFor: 'as yet unclassified' stamp: 'it 5/11/2013 19:42'!
testDoLoginWithWrongPassword
	"comment stating purpose of message"

	user username: 'user'; password: 'q'; name: 'Leonardo Santos'; email: 'admin@flodactic.org'; withAdminPrivileges; doEnable.
	
	self should: [usersManager doLogin: 'user' password: 'wrong'.] raise: PermissionError! !

!UsersManagerTests methodsFor: 'as yet unclassified' stamp: 'it 5/11/2013 19:45'!
testRemoveWithNonExistingUsername
	"comment stating purpose of message"

	user password: 'q'; name: 'Leonardo Santos'; email: 'leo@flodactic.org'; withAdminPrivileges; doEnable.
	
	self should: [usersManager remove: 'aasdasda'.] raise: Error! !

TestCase subclass: #WorkspaceTestExample
	instanceVariableNames: 'albertAuthor ui01 ui02 ui03 admin01 moderator01 moderator02 albertUser igorUser material01 material02 floogle ui04 tagPython tagTutorial'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FLOdactic-Tests'!

WorkspaceTestExample class
	instanceVariableNames: 'ui01 ui02 admin01 moderator01 moderator02 albertAuthor material01 material02 floogle albertUser igorUser'!

WorkspaceTestExample class
	instanceVariableNames: 'ui01 ui02 admin01 moderator01 moderator02 albertAuthor material01 material02 floogle albertUser igorUser'!

!WorkspaceTestExample methodsFor: 'as yet unclassified' stamp: 'afv 5/11/2013 19:42'!
editUserFailed
	"Use of updateUser without being logged in"


	"Add special users to the session"
	ui01 addUser: admin01.
	ui01 addUser: moderator01.
	ui01 addUser: moderator02.
	
	ui01 addUser: albertUser.
	ui01 doLogin: 'albert' password: 'q'.
	ui01 doLogout.
	self assert: ((ui01 loggedUser) = nil).
	
	"Let's edit (update) the user's email address"
	albertUser username: 'albert'; password: 'q'; name: 'Albert De La Fuente'; email: 'albert@ime.usp.br'; withUserPrivileges; doEnable.
	self should: [ui01 updateUser: albertUser.] raise: Exception.! !

!WorkspaceTestExample methodsFor: 'as yet unclassified' stamp: 'afv 5/11/2013 20:21'!
setUp
	"Create the user's interface"
"	ui01 ifNotNil: [
		ui01 release.
	].
	ui02 ifNotNil: [
		ui02 release.
	].
	ui03 ifNotNil: [
		ui03 release.
	].
	ui04 ifNotNil: [
		ui04 release.
	]."

	Transcript show: 'Creating structures...'; crlf.
	ui01 := FLOdacticFacade new.
	ui02 := FLOdacticFacade new.
	ui03 := FLOdacticFacade new.
	ui04 := FLOdacticFacade new.	

	"Authors objects (these are not unique, they are treated as a stamp information on every document)"
	Transcript show: 'Creating authors...'; crlf.
	albertAuthor := Author new.
	albertAuthor name: 'Albert De La Fuente'.
	
	"Create special users objects"
	Transcript show: 'Creating users...'; crlf.
	admin01 := User new.
	moderator01 := User new.
	moderator02 := User new.
	
	admin01 username: 'admin01'; password: 'q'; name: 'Leonardo Santos'; email: 'admintest@flodactic.org'; withAdminPrivileges; doEnable.
	moderator01 username: 'mod01'; password: 'q'; name: 'Rodolpho Bustamante'; email: 'mod01test@flodactic.org'; withModeratorPrivileges; doEnable.
	moderator02 username: 'mod02'; password: 'q'; name: 'Samuel Rodrigues'; email: 'mod02test@flodactic.org'; withModeratorPrivileges; doEnable.
	
	"Create regular users objects"
	albertUser := User new.
	igorUser := User new.
	
	albertUser username: 'albert'; password: 'q'; name: 'Albert De La Fuente'; email: 'albert@ime.usp.br'; withUserPrivileges; doEnable.
	igorUser username: 'igor'; password: 'q'; name: 'Igor Topcin'; email: 'igor@ime.usp.br'; withUserPrivileges; doEnable.
	
	"didacticMaterialManager := DidacticMaterialsManager singleton."
	Transcript show: 'Creating didactic materials...'; crlf.
	material01 := DidacticMaterial new.
	material02 := DidacticMaterial new.
	
"	
	tagPython := Tag new; name: 'Python'.
	tagTutorial := Tag new; name: 'Tutorial'.
	tagLDAP := Tag new; name: 'Tutorial'.
	tagTutorial := Tag new; name: 'Tutorial'."
	
	material01 uri: 'http://www.albertdelafuente.com/doku.php/wiki/devel/python/ldap-auth';
		title: 'Python LDAP tutorial';
		description: 'A tutorial on how to use an LDAP server on Python';
		type: 'document';
		license: 'cc';
		addAuthor: albertAuthor;
		addTag: 'Python';
		addTag: 'Tutorial';
		addTag: 'LDAP'.

	material02 uri: 'http://www.albertdelafuente.com/doku.php/wiki/devel/python/whatsapp-api';
		title: 'Python Whatsapp tutorial';
		description: 'A tutorial on how to use an Whatsapp API on Python';
		type: 'document';
		license: 'cc';
		addTag: 'Python';
		addTag: 'Tutorial';
		addTag: 'Whatsapp'.
	
	"Create a SearchEngine"
	Transcript show: 'Creating search engine...'; crlf.
	floogle := SearchEngine new.
	
	"r1 := dm select: [:doc | ('*' match: doc title)].
	r2 := dm select: [:doc | ('*' match: doc title)]."

	"Create regular users objects"

! !

!WorkspaceTestExample methodsFor: 'as yet unclassified' stamp: 'afv 5/11/2013 12:25'!
tearDown
	"User's interface"
	ui01 removeAll.
	ui02 removeAll.
	ui03 removeAll.
	ui04 removeAll.
	
	ui01 release.
	ui02 release.
	ui03 release.
	ui04 release.
	
	"Special users objects"
	admin01 release.
	moderator01 release.
	moderator02 release.
	
	"Authors objects"
	"albertAuthor release."
	
	"didacticMaterialManager := DidacticMaterialsManager singleton."
	material01 release.
	material02 release.
	
	"SearchEngine"
	floogle release.
	
	"r1 := dm select: [:doc | ('*' match: doc title)].
	r2 := dm select: [:doc | ('*' match: doc title)]."

	"Create regular users objects"
	albertUser release.
	igorUser release.
! !

!WorkspaceTestExample methodsFor: 'as yet unclassified' stamp: 'afv 6/8/2013 10:21'!
testWorkspace
	"This is an example of a possible use case of FLOdactic."

	| rawSearch search rawSearch1 rawSearch2 |

	"Add special users to the session"
	ui01 addUser: admin01.
	ui01 addUser: moderator01.
	ui01 addUser: moderator02.
	
	ui01 addUser: albertUser.
	ui01 doLogin: 'albert' password: 'q'.
	ui01 loggedUser.

	ui01 addMaterial: material01.
	ui01 addMaterial: material02.
	
	self assert: ((material01 matchesByOwnerName: 'Albert De La Fuente') = true).	
	self assert: ((albertUser isUser) = true).
	self assert: ((albertUser isDisabled) = false).

	floogle := SearchEngine new.
	rawSearch := floogle searchDidacticMaterials: 'Python'.
	
	search := floogle addFilter: (Filter didacticMaterialsByAuthorName: 'Albert De La Fuente').
	self assert: ((search size) = 1).
	
	floogle := SearchEngine new.
	rawSearch := floogle searchDidacticMaterials: 'Python'.
	

	search := floogle addFilter: (Filter didacticMaterialsByDescription: 'tutorial').
	self assert: ((search size) = 2).

	search := floogle addFilter: (Filter didacticMaterialsByStatus: 'enabled').
	self assert: ((search size) = 2).
	
	search := floogle addFilter: (Filter didacticMaterialsByStatus: 'enabled').
	self assert: ((search size) = 2).

	search := floogle addFilter: (Filter didacticMaterialsByTitle: 'Python').
	self assert: ((search size) = 2).

	search := floogle addFilter: (Filter didacticMaterialsByType: 'document').
	self assert: ((search size) = 2).
	
	search := floogle addFilter: (Filter didacticMaterialsByTag: 'Python').
	self assert: ((search size) = 2).
	
	"r1 := dm select: [:doc | ('*' match: doc title)].
	r2 := dm select: [:doc | ('*' match: doc title)]."

	"Add them to the FLOdactic User's Interface"
	
	"albert is logged in ui01"
	self assert: ((ui01 canRemove: albertUser) = true).
	self assert: ((ui01 canEdit: albertUser) = true).
	"The user can edit / delete it's own materials"
	self assert: ((ui01 canRemove: material01) = true).
	"Users cannot block users nor materials"
	self assert: ((ui01 canEdit: material01) = true).
	self assert: ((ui01 canDisable: albertUser) = false).
	self assert: ((ui01 canDisable: material01) = false).
	self assert: ((ui01 canDisable: igorUser) = false).

	ui02 doLogin: 'admin01' password: 'q'.
	"admin01, is logged in ui01. who can also edit / delete any user and document"
	self assert: ((ui02 canRemove: albertUser) = true).
	self assert: ((ui02 canEdit: albertUser) = true).
	self assert: ((ui02 canRemove: material01) = true).
	self assert: ((ui02 canEdit: material01) = true).
	"Only administrators can block users and didactic materials"
	self assert: ((ui02 canDisable: albertUser) = true).
	self assert: ((ui02 canDisable: material01) = true).
		
	ui03 doLogin: 'mod01' password: 'q'.
	"moderator01, is logged in ui03. who can also edit / delete any document, but not user"
	self assert: ((ui03 canRemove: albertUser) = false).
	self assert: ((ui03 canEdit: albertUser) = false).
	self assert: ((ui03 canRemove: material01) = true).
	self assert: ((ui03 canEdit: material01) = true).
	"Moderators can block only didactic materials"
	self assert: ((ui03 canDisable: albertUser) = false).
	self assert: ((ui03 canDisable: material01) = true).
	
	ui04 addUser: igorUser.
	ui04 doLogin: 'igor' password: 'q'.
	"This is a regular user (who's not the user itself), he can't edit / delete"
	self assert: ((ui04 canRemove: albertUser) = false).
	self assert: ((ui04 canEdit: albertUser) = false).
	"This user cannot edit / delete material01, since albert haven't yet authorized to do so"	
	self assert: ((ui04 canRemove: material01) = false).
	self assert: ((ui04 canEdit: material01) = false).

	"Permission granted as contributor"	
	ui01 addContributor: igorUser didacticMaterial: material02.
	self assert: ((material02 matchesContributorsByName: 'Igor Topcin') = false).
	
	"This is a regular user (who's not the user itself), he can't edit / delete"
	self assert: ((ui04 canRemove: albertUser) = false).
	self assert: ((ui04 canEdit: albertUser) = false).
	self assert: ((ui04 canDisable: albertUser) = false).
	"This user now can edit but not delete material01, since albert has authorized to do so"	
	self assert: ((ui04 canRemove: material02) = false).
	self assert: ((ui04 canEdit: material02) = true).
	self assert: ((ui04 canDisable: material02) = false).

	"Igor is editing Alberts material"
	Transcript show: 'Igor is editing Alberts material';cr.
"	material02Edited := material02 deepCopy."
	material02 addAuthor: albertAuthor.
	ui04 editDidacticMaterial: material02.

	"Search by author's name"	
	rawSearch := floogle searchDidacticMaterials: '*'.
	search := floogle addFilter: (Filter didacticMaterialsByAuthorName: 'Albert De La Fuente').
	self assert: ((search size) = 2).
	
	"Let's edit (update) the user's email address"
	albertUser username: 'albert'; password: 'q'; name: 'Albert De La Fuente'; email: 'albert@ime.usp.br'; withUserPrivileges; doEnable.
	ui01 editUser: albertUser.
	self assert: ((ui01 loggedUser email) = 'albert@ime.usp.br').

	"Search a didactic material by the owner's name"
	rawSearch := floogle searchDidacticMaterials: '*'.
	search := floogle addFilter: (Filter didacticMaterialsByOwnerName: 'Albert').
	self assert: ((rawSearch size) = 2).
	
	"Search a didactic material by the owner's email"
	rawSearch := floogle searchDidacticMaterials: '*'.
	search := floogle addFilter: (Filter didacticMaterialsByOwnerEmail: 'albert@ime.usp.br').
	self assert: ((rawSearch size) = 2).
	
	"Search all users"
	rawSearch := floogle searchUsers: '*'.
	self assert: ((rawSearch size) = 5).
	
	"Filter only administrators"
	search := floogle addFilter: (Filter usersByRole: 'administrator').
	self assert: ((search size) = 1).
	
	"Filter only regular users"
	search := floogle addFilter: (Filter usersByRole: 'user').
	self assert: ((search size) = 2).

	"Igor tries to remove the didactic material (why!!!!!!!!?)"
	rawSearch1 := floogle searchDidacticMaterials: '*'.
	ui04 removeDidacticMaterial: material02.
	rawSearch2 := floogle searchDidacticMaterials: '*'.
	self assert: ((rawSearch1 size) = (rawSearch2 size)).

	rawSearch1 := ui04 searchDidacticMaterials: '*'.
	
	"Igor reports for removal to the moderators"
	self assert: ((material02 isBlocked) = false).
	ui04 feedbackBlock: material02.
	self assert: ((material02 isBlocked) = true).
	self assert: ((material02 isEnabled) = false).
	self assert: ((material02 status) = 'blocked').
	
	"Moderator mod01 disables material02, we counted the
	number of items in rawSearch1 before Igor's request (see 5 lines before)"
	ui03 feedbackDisable: material02.
	self assert: ((material02 isDisabled) = true).
	rawSearch2 := ui04 searchDidacticMaterials: '*'.
	self assert: ((rawSearch1 size) = (rawSearch2 size + 1)).

	"Enable back a material. Only admins can do that"
	rawSearch2 := ui04 searchDidacticMaterials: '*'. "Igor's count"	
	ui02 feedbackEnable: material02.
	rawSearch1 := ui04 searchDidacticMaterials: '*'. "Igor's count"	
	self assert: ((rawSearch1 size) = (rawSearch2 size + 1)).
	
	"Moderator mod01 removes the didactic material"
	rawSearch1 := floogle searchDidacticMaterials: '*'.
	ui03 removeDidacticMaterial: material02.
	rawSearch2 := floogle searchDidacticMaterials: '*'.
	self assert: ((rawSearch1 size) = (rawSearch2 size + 1)).

	"Albert reports Igor"	
	self assert: ((igorUser isBlocked) = false).
	ui04 feedbackBlock: igorUser.
	self assert: ((igorUser isBlocked) = true).
	
	"Admin disables Igor"
	ui02 feedbackDisable: igorUser.
	self assert: ((igorUser isDisabled) = true).

	ui04 doLogout.
	self should: [ui04 doLogin: 'igor' password: 'q'] raise: PermissionError.

	"Administrator removes Igor"
	rawSearch1 := floogle searchUsers: '*'.
	ui02 removeUser: 'igor'.
	rawSearch2 := floogle searchUsers: '*'.
	self assert: ((rawSearch1 size) = (rawSearch2 size + 1)).
	
	"And Albert too"
	rawSearch1 := floogle searchUsers: '*'.
	ui02 removeUser: 'albert'.
	rawSearch2 := floogle searchUsers: '*'.
	self assert: ((rawSearch1 size) = (rawSearch2 size + 1)).! !

!WorkspaceTestExample methodsFor: 'as yet unclassified' stamp: 'afv 4/30/2013 21:24'!
testWorkspaceCommented
	"This is not really a test, is a 'persistent workspace' in order to be able to use it over git"
"
admin := User new.
admin username: 'admin'; password: 'q'; name: 'Leonardo Santos'; email: 'admin@flodactic.org'; role: 'administrator'; status: 'enabled'.
mod01 := User new.
mod01 username: 'mod01'; password: 'q'; name: 'Rodolpho Bustamante'; email: 'mod01@flodactic.org'; role: 'moderator'; status: 'enabled'.
mod02 := User new.
mod02 username: 'mod02'; password: 'q'; name: 'Rodolpho Bustamante'; email: 'mod02@flodactic.org'; role: 'moderator'; status: 'enabled'.

albert := User new.
albert username: 'vonpupp'; password: 'q'; name: 'Albert De La Fuente'; email: 'albert@ime.usp.br'; role: 'user'; status: 'enabled'.

igor := User new.
igor username: 'topcin'; password: 'q'; name: 'Igor Topcin'; email: 'topcin@ime.usp.br'; role: 'user'; status: 'enabled'.

usersManager := UserManager new.
usersManager add: admin.
usersManager add: mod01.
usersManager add: mod02.
usersManager add: albert.
usersManager add: igor.

* Create a tag (which way?)
pythonTag := Tag new: 'python'.
ldapTag := Tag new: 'LDAP'.
programmingTag := Tag new: 'programming'.
tagsManager := TagsManager new.

* Create a material
didacticMaterial := DidacticMaterial new.
didacticMaterial uri: 'http://www.albertdelafuente.com/doku.php/wiki/devel/python/ldap-auth';
				 owner: albert;
				 title: 'Python LDAP authentication';
				 tags: tags.


* Brainstorm inicial (Albert)
documento := Material new.
documento url: 'http://www.ex.com/doc.pdf' titulo: 'tutorial de Smalltalk'...
tags := ListaTags new.
tags adicionar: 'squeak' adicionar: 'desenvolvimento' adicionar: 'programacao orientada a objetos'
ca := ControleAcesso new.
ca usuario: albert material: documento permissao: modificacao receptor: albert

tags := ListaTags new.
tags adicionar: 'squeak'
busca := Buscar new.
busca usuario: albert chave: 'manual de smalltalk' tags: tags

igor := Usuario new.
igor email: 'igortopcin@gmail.com' nome: 'Igor' sobrenome: 'Topcin' senha: '1234'
usuarios := ListaUsuarios new. (herda de Collection ou List por exemplo)
usuarios adicionar: igor

sessao...

ca usuario: albert material: documento permissao: modificacao receptor: igor
documento titulo: 'tutorial de Squeak'
log acao: modificao material: documento campo: titulo por: igor no: dia

"! !
